@@ -25,33 +25,43 @@ class H2OMOJOSettings(JavaWrapper):
     def __init__(self,
                  predictionCol="prediction",
                  detailedPredictionCol="detailed_prediction",
-                 withDetailedPredictionCol=False,
+                 withDetailedPredictionCol=True,
                  convertUnknownCategoricalLevelsToNa=False,
                  convertInvalidNumbersToNa=False,
-                 namedMojoOutputColumns=True):
+                 namedMojoOutputColumns=True,
+                 withContributions=False,
+                 withLeafNodeAssignments=False,
+                 withStageResults=False):
         self._java_obj = None
 
         assert_is_type(predictionCol, str)
         assert_is_type(detailedPredictionCol, str)
-        assert_is_type(withDetailedPredictionCol, bool)
         assert_is_type(convertUnknownCategoricalLevelsToNa, bool)
         assert_is_type(convertInvalidNumbersToNa, bool)
         assert_is_type(namedMojoOutputColumns, bool)
+        assert_is_type(withContributions, bool)
+        assert_is_type(withLeafNodeAssignments, bool)
+        assert_is_type(withStageResults, bool)
         self.predictionCol = predictionCol
         self.detailedPredictionCol = detailedPredictionCol
-        self.withDetailedPredictionCol = withDetailedPredictionCol
         self.convertUnknownCategoricalLevelsToNa = convertUnknownCategoricalLevelsToNa
         self.convertInvalidNumbersToNa = convertInvalidNumbersToNa
         self.namedMojoOutputColumns = namedMojoOutputColumns
+        self.withContributions = withContributions
+        self.withLeafNodeAssignments = withLeafNodeAssignments
+        self.withStageResults = withStageResults
 
     def toJavaObject(self):
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.models.H2OMOJOSettings",
                                             self.predictionCol,
                                             self.detailedPredictionCol,
-                                            self.withDetailedPredictionCol,
+                                            True,
                                             self.convertUnknownCategoricalLevelsToNa,
                                             self.convertInvalidNumbersToNa,
-                                            self.namedMojoOutputColumns)
+                                            self.namedMojoOutputColumns,
+                                            self.withContributions,
+                                            self.withLeafNodeAssignments,
+                                            self.withStageResults)
         return self._java_obj
 
     @staticmethod
