@@ -261,6 +261,12 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
         """Which GPU to use. """,
         H2OTypeConverters.toInt())
 
+    interactionConstraints = Param(
+        Params._dummy(),
+        "interactionConstraints",
+        """A set of allowed column interactions.""",
+        H2OTypeConverters.toNullableListListString())
+
     modelId = Param(
         Params._dummy(),
         "modelId",
@@ -387,6 +393,12 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
         """Automatically export generated models to this directory.""",
         H2OTypeConverters.toNullableString())
 
+    aucType = Param(
+        Params._dummy(),
+        "aucType",
+        """Set default multinomial AUC type.""",
+        H2OTypeConverters.toEnumString("hex.MultinomialAucType"))
+
     ##
     # Getters
     ##
@@ -507,6 +519,9 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def getGpuId(self):
         return self.getOrDefault(self.gpuId)
 
+    def getInteractionConstraints(self):
+        return self.getOrDefault(self.interactionConstraints)
+
     def getModelId(self):
         return self.getOrDefault(self.modelId)
 
@@ -570,6 +585,9 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def getExportCheckpointsDir(self):
         return self.getOrDefault(self.exportCheckpointsDir)
 
+    def getAucType(self):
+        return self.getOrDefault(self.aucType)
+
     ##
     # Setters
     ##
@@ -690,6 +708,9 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
     def setGpuId(self, value):
         return self._set(gpuId=value)
 
+    def setInteractionConstraints(self, value):
+        return self._set(interactionConstraints=value)
+
     def setModelId(self, value):
         return self._set(modelId=value)
 
@@ -752,3 +773,6 @@ class H2OXGBoostParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnor
 
     def setExportCheckpointsDir(self, value):
         return self._set(exportCheckpointsDir=value)
+
+    def setAucType(self, value):
+        return self._set(aucType=value)
